@@ -4,7 +4,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -39,7 +39,7 @@
 
 typedef jack_default_audio_sample_t sample_t;
 
-static const size_t rb_n_samples = 10000;	/* maximum number of samples to hold in the ring buffer */
+static const size_t rb_n_samples = 10000;       /* maximum number of samples to hold in the ring buffer */
 static uint32_t encoder_packet_magic_number = 'I' << 24 | 'D' << 16 | 'J' << 8 | 'C';
 
 int encoder_init_lame(struct threads_info *ti, struct universal_vars *uv, void *param)
@@ -151,13 +151,13 @@ static long encoder_input_rb_mono_downmix(jack_ringbuffer_t **rb, float *bptr, i
    /* transition is the point at the end of the ringbuffer where we must wrap around */
    if((transition = rbvec0[0].len / sizeof (sample_t)) > n_samples)
       transition = n_samples;
-   ch0 = (sample_t *)rbvec0[0].buf;	/* set channel 0 and 1 pointers */
+   ch0 = (sample_t *)rbvec0[0].buf;     /* set channel 0 and 1 pointers */
    ch1 = (sample_t *)rbvec1[0].buf;
    for (i = 0; i < transition; i++)
-      *bptr++ = (*ch0++ + *ch1++) * 0.5F;	/* copy up to the transition */
-   ch0 = (sample_t *)rbvec0[1].buf;	/* set pointers for segment 2 */
+      *bptr++ = (*ch0++ + *ch1++) * 0.5F;       /* copy up to the transition */
+   ch0 = (sample_t *)rbvec0[1].buf;     /* set pointers for segment 2 */
    ch1 = (sample_t *)rbvec1[1].buf;
-   for (i = transition; i < n_samples; i++)	/* do the second segment if relevant */
+   for (i = transition; i < n_samples; i++)     /* do the second segment if relevant */
       *bptr++ = (*ch0++ + *ch1++) * 0.5F;
    jack_ringbuffer_read_advance(rb[0], n_samples * sizeof (sample_t));
    jack_ringbuffer_read_advance(rb[1], n_samples * sizeof (sample_t));
@@ -244,7 +244,7 @@ struct encoder_ip_data *encoder_get_input_data(struct encoder *encoder, int min_
          id->qty_samples = encoder_input_rb_mono_downmix(encoder->input_rb, id->buffer[0], max_samples);
       }
    else
-      {			/* handle the resampling condition */
+      {                 /* handle the resampling condition */
       /* note 128 samples are held back to make sure the resampler gives the full number of samples on both reads */
       samples_available = (int)(jack_ringbuffer_read_space(encoder->input_rb[1]) / sizeof (sample_t)) * encoder->sr_conv_ratio - 128.0;
       if (samples_available > max_samples)
@@ -424,7 +424,7 @@ struct encoder_op *encoder_register_client(struct threads_info *ti, int numeric_
 void encoder_unregister_client(struct encoder_op *op)
    {
    struct encoder_op *iter;
-   struct timespec ms10 = { 0, 10000000 };	/* ten milliseconds */
+   struct timespec ms10 = { 0, 10000000 };      /* ten milliseconds */
    
    fprintf(stderr, "encoder_unregister_client called\n");
    while (pthread_mutex_trylock(&op->encoder->mutex))
@@ -448,7 +448,7 @@ void encoder_unregister_client(struct encoder_op *op)
 void *encoder_main(void *args)
    {
    struct encoder *self = args;
-   struct timespec ms10 = { 0, 10000000 };	/* ten milliseconds */
+   struct timespec ms10 = { 0, 10000000 };      /* ten milliseconds */
 
    while(!self->thread_terminate_f)
       {
@@ -611,6 +611,9 @@ int encoder_new_metadata(struct threads_info *ti, struct universal_vars *uv, voi
       for (uv->tab = 0; uv->tab < ti->n_encoders; uv->tab++)
          if (!(encoder_new_metadata(ti, uv, other)))
             return FAILED;
+      for (int i = 0; i < ti->n_recorders; i++)
+         if (!(recorder_new_metadata(ti->recorder[i], ev->artist, ev->title)))
+            return FAILED;  
       }
    else
       {
@@ -731,5 +734,14 @@ void encoder_destroy(struct encoder *self)
       free(self->metaformat);
    if (self->metaformat_mp3)
       free(self->metaformat_mp3);
+   if (self->artist)
+      free(self->artist);
+   if (self->title)
+      free(self->title);
+   if (self->artist_title)
+      free(self->artist_title);
+   if (self->artist_title_mp3)
+      free(self->artist_title_mp3);
    free(self);
    }
+
