@@ -27,6 +27,7 @@
 #include <jack/transport.h>
 #include <jack/ringbuffer.h>
 #include <jack/statistics.h>
+#include <jack/midiport.h>
 #include <getopt.h>
 #include <string.h>
 #include <fcntl.h>
@@ -56,6 +57,8 @@
 #define RB_SIZE 10.0
 /* number of samples in the fade (ring) buffer */
 #define FB_SIZE (RB_SIZE * sr)
+/* number of bytes in the MIDI queue buffer */
+#define MIDI_QUEUE_SIZE 1024
 
 /* the different VOIP modes */
 #define NO_PHONE 0
@@ -65,7 +68,7 @@
 typedef jack_default_audio_sample_t sample_t;
 
 /* values of the volume sliders in the GUI */
-int volume, crossfade, jinglesvolume, interludevol, mixbackvol, crosspattern;
+int volume, volume2, crossfade, jinglesvolume, interludevol, mixbackvol, crosspattern;
 /* back and forth status indicators re. jingles */
 int jingles_playing, jingles_audio_f;
 /* used for gapless playback to indicate an almost empty buffer */
@@ -79,7 +82,7 @@ int aux_flux;
 /* simple mixer mode: uses less space on the screen and less cpu as well */
 int simple_mixer;
 /* currentvolumes are used to implement volume smoothing */
-int current_volume, current_jingles_volume, current_interlude_volume,
+int current_volume, current_volume2, current_jingles_volume, current_interlude_volume,
     current_crossfade, currentmixbackvol, current_crosspattern; 
 /* the id. number microphone filter we are using */
 int mic_filter;
@@ -203,6 +206,11 @@ jack_port_t *phone_left_send;   /* used for VOIP */
 jack_port_t *phone_right_send;
 jack_port_t *phone_left_recv;
 jack_port_t *phone_right_recv;
+jack_port_t *midi_port; /* midi_control */
+
+char midi_queue[MIDI_QUEUE_SIZE];
+size_t midi_nqueued= 0;
+pthread_mutex_t midi_mutex;
 
 unsigned long sr;               /* the sample rate reported by JACK */
 
@@ -214,7 +222,7 @@ struct xlplayer *plr_l, *plr_r, *plr_j, *plr_i; /* pipe reader instance stucture
 /* these are set in the parse routine - the contents coming from the GUI */
 char *mixer_string, *compressor_string, *gate_string, *microphone_string;
 char *normalizer_string, *new_mic_string;
-char *micl, *micr, *auxl, *auxr, *audl, *audr, *strl, *strr, *action;
+char *micl, *micr, *auxl, *auxr, *midi, *audl, *audr, *strl, *strr, *action;
 char *mic1, *mic2, *mic3, *mic4;
 char *dol, *dor, *dil, *dir;
 char *oggpathname, *sndfilepathname, *avformatpathname, *speexpathname, *speextaglist, *speexcreatedby;
@@ -243,6 +251,7 @@ struct kvpdict kvpdict[] = {
          { "MIC4", &mic4 },
          { "AUXL", &auxl },
          { "AUXR", &auxr },
+         { "MIDI", &midi },
          { "AUDL", &audl },
          { "AUDR", &audr },
          { "STRL", &strl },
@@ -308,7 +317,8 @@ void handle_mute_button(sample_t *gainlevel, int switchlevel)
 /* update_smoothed_volumes: stuff that gets run once every 32 samples */
 void update_smoothed_volumes()
    {
-   static sample_t vol_rescale = 1.0F, jingles_vol_rescale = 1.0F, interlude_vol_rescale = 1.0F, cross_left = 1.0F, cross_right = 0.0F, mixback_rescale = 1.0F;
+   static sample_t vol_rescale = 1.0F, vol2_rescale = 1.0F, jingles_vol_rescale = 1.0F, interlude_vol_rescale = 1.0F;
+   static sample_t cross_left = 1.0F, cross_right = 0.0F, mixback_rescale = 1.0F;
    static sample_t lp_listen_mute = 1.0F, rp_listen_mute = 1.0F, lp_stream_mute = 1.0F, rp_stream_mute = 1.0F;
    sample_t mic_target, diff;
    static float interlude_autovol = -128.0F, old_autovol = -128.0F;
@@ -384,6 +394,14 @@ void update_smoothed_volumes()
          current_volume--;
       vol_rescale = 1.0F/powf(10.0F,current_volume/55.0F);      /* a nice logarithmic volume scale */
       }
+   if (volume2 != current_volume2)
+      {
+      if (volume2 > current_volume2)
+         current_volume2++;
+      else
+         current_volume2--;
+      vol2_rescale = 1.0F/powf(10.0F,current_volume2/55.0F);
+      }
       
    if (jinglesvolume != current_jingles_volume)
       {
@@ -438,9 +456,9 @@ void update_smoothed_volumes()
    
    /* the factors that will be applied in the mix on the media players */
    lp_lc_aud = lp_rc_aud = vol_rescale * lp_listen_mute;
-   rp_lc_aud = rp_rc_aud = vol_rescale * rp_listen_mute;
+   rp_lc_aud = rp_rc_aud = vol2_rescale * rp_listen_mute;
    lp_lc_str = lp_rc_str = vol_rescale * cross_left * lp_stream_mute;
-   rp_lc_str = rp_rc_str = vol_rescale * cross_right * rp_stream_mute;
+   rp_lc_str = rp_rc_str = vol2_rescale * cross_right * rp_stream_mute;
    jp_lc_str = jp_rc_str = jp_lc_aud = jp_rc_aud = jingles_vol_rescale;
    mb_lc_aud = mb_rc_aud = mixback_rescale;
    ip_lc_aud = ip_rc_aud = 0.0F;
@@ -464,12 +482,11 @@ void update_smoothed_volumes()
             }
       }
 
-   /* calculate the ducking factor reduction based on gain controls */
    if (jingles_playing)
       vol = current_jingles_volume * 0.06666666F;
    else
-      vol = current_volume * 0.06666666F;
-   dfmod = 1.0F / (vol * vol + 1.0F);
+      vol = (current_volume - (current_volume - current_volume2) / 2.0F) * 0.06666666F;
+   dfmod = vol * vol + 1.0F;
    }
 
 /* update_mic_and_aux: provide gradual mute/unmute for aux button */
@@ -530,6 +547,12 @@ void process_audio(jack_nframes_t nframes)
    /* temporary storage for processed fade values */
    sample_t lp_lc_fade, lp_rc_fade, rp_lc_fade, rp_rc_fade;
    sample_t jp_lc_fade, jp_rc_fade, ip_lc_fade, ip_rc_fade;
+   /* midi_control */
+   void *midi_buffer;
+   jack_midi_event_t midi_event;
+   jack_nframes_t midi_nevents, midi_eventi;
+   int midi_command_type, midi_channel_id;
+   int pitch_wheel;
 
    if (timeout > 8000)
       {
@@ -544,6 +567,60 @@ void process_audio(jack_nframes_t nframes)
       plr_i->command = CMD_COMPLETE;
       }
 
+   /* midi_control. read incoming commands forward to gui */
+   midi_buffer = jack_port_get_buffer(midi_port, nframes);
+   midi_nevents = jack_midi_get_event_count(midi_buffer);
+   if (midi_nevents!=0)
+      {
+      pthread_mutex_lock(&midi_mutex);
+      for (midi_eventi = 0; midi_eventi < midi_nevents; midi_eventi++)
+         {
+         if (jack_midi_event_get(&midi_event, midi_buffer, midi_eventi) != 0)
+            {
+            fprintf(stderr, "Error reading MIDI event from JACK\n");
+            continue;
+            }
+         if  (midi_nqueued+12 > MIDI_QUEUE_SIZE) /* max length of command */
+            {
+            fprintf(stderr, "MIDI queue overflow, event lost\n");
+            continue;
+            }
+         midi_command_type= midi_event.buffer[0] & 0xF0;
+         midi_channel_id= midi_event.buffer[0] & 0x0F;
+         switch (midi_command_type)
+            {
+            case 0xB0: /* MIDI_COMMAND_CHANGE */
+               midi_nqueued+= snprintf(
+                  midi_queue+midi_nqueued, MIDI_QUEUE_SIZE-midi_nqueued,
+                  ",c%x.%x:%x", midi_channel_id, midi_event.buffer[1], midi_event.buffer[2]
+               );
+               break;
+            case 0x80: /* MIDI_NOTE_OFF */
+               midi_nqueued+= snprintf(
+                  midi_queue+midi_nqueued, MIDI_QUEUE_SIZE-midi_nqueued,
+                  ",n%x.%x:0", midi_channel_id, midi_event.buffer[1]
+               );
+               break;
+            case 0x90: /* MIDI_NOTE_ON */
+               midi_nqueued+= snprintf(
+                  midi_queue+midi_nqueued, MIDI_QUEUE_SIZE-midi_nqueued,
+                  ",n%x.%x:7F", midi_channel_id, midi_event.buffer[1]
+               );
+               break;
+            case 0xFE: /* MIDI_PITCH_WHEEL_CHANGE */
+               pitch_wheel= 0x2040 - midi_event.buffer[2] - midi_event.buffer[1]*128;
+               if (pitch_wheel < 0) pitch_wheel = 0;
+               if (pitch_wheel > 0x7F) pitch_wheel = 0x7F;
+               midi_nqueued+= snprintf(
+                  midi_queue+midi_nqueued, MIDI_QUEUE_SIZE-midi_nqueued,
+                  ",p%x.0:%x", midi_channel_id, pitch_wheel
+               );
+               break;
+            }
+         }
+      pthread_mutex_unlock(&midi_mutex);
+      }
+
    /* get the data for the jack ports */
    la_buffer = lap = (sample_t *) jack_port_get_buffer (audio_left_port, nframes);
    ra_buffer = rap = (sample_t *) jack_port_get_buffer (audio_right_port, nframes);
@@ -688,7 +765,7 @@ void process_audio(jack_nframes_t nframes)
              
              float w1 = (df1 < df2) ? df1 : df2;
              float w2 = (df3 < df4) ? df3 : df4;
-             df = (w1 < w2) ? w1 : w2;
+             df = ((w1 < w2) ? w1 : w2) * dfmod;
              df = (df < hr) ? df : hr;
          }
 
@@ -1181,7 +1258,7 @@ void process_audio(jack_nframes_t nframes)
                       
                       float w1 = (df1 < df2) ? df1 : df2;
                       float w2 = (df3 < df4) ? df3 : df4;
-                      df = (w1 < w2) ? w1 : w2;
+                      df = ((w1 < w2) ? w1 : w2) * dfmod;
                       df = (df < hr) ? df : hr;
                   }
                      
@@ -1438,6 +1515,7 @@ void alarm_handler(int data)
 void atexit_handler()
    {
    if (client)
+      jack_deactivate(client);
       jack_client_close(client);
    }
 
@@ -1492,6 +1570,11 @@ int main(int argc, char **argv)
    int use_dsp;
    jack_status_t status;
    char *server_name = getenv("IDJC_JACK_SERVER");
+   char midi_output[MIDI_QUEUE_SIZE];
+   char *our_sc_str_in_l;
+   char *our_sc_str_in_r;
+   char *sc_client_name = getenv("sc_client_id");
+   int l;
 
    setenv("LC_ALL", "C", 1);            /* ensure proper sscanf operation */
 
@@ -1507,7 +1590,7 @@ int main(int argc, char **argv)
    have_mad = 1;
 #endif /* DYN_MAD */
 
-   if((client = jack_client_open("idjc-mx", JackUseExactName | JackServerName, &status, server_name)) == 0)
+   if((client = jack_client_open(getenv("mx_client_id"), JackUseExactName | JackServerName, &status, server_name)) == 0)
       {
       printf("IDJC: Error\n");
       fflush(stdout);
@@ -1562,6 +1645,20 @@ int main(int argc, char **argv)
    phone_right_recv = jack_port_register(client, "voip_in_r", JACK_DEFAULT_AUDIO_TYPE,
                                         JackPortIsInput, 0);
 
+   /* midi_control */
+   midi_port = jack_port_register(client, "midi_control", JACK_DEFAULT_MIDI_TYPE, JackPortIsInput, 0);
+
+   l = strlen(sc_client_name) + 10;
+   our_sc_str_in_l = malloc(l);
+   our_sc_str_in_r = malloc(l);
+   if ((!our_sc_str_in_l) || (!our_sc_str_in_r))
+      {
+      fprintf(stderr, "malloc failure\n");
+      return 1;
+      }
+   snprintf(our_sc_str_in_l, l, "%s:%s", sc_client_name, "str_in_l");
+   snprintf(our_sc_str_in_r, l, "%s:%s", sc_client_name, "str_in_r");
+
    sr = jack_get_sample_rate(client);
    fb_size = FB_SIZE;
    jingles_samples_cutoff = sr / 12;            /* A twelfth of a second early */
@@ -1868,15 +1965,14 @@ int main(int argc, char **argv)
       if (!strcmp(action, "mixstats"))
          {
          if(sscanf(mixer_string,
-                ":%03d:%03d:%03d:%03d:%03d:%d:%1d%1d%1d%1d%1d:%1d%1d:%1d:%1d%1d%1d%1d:%1d:%1d:%1d:%1d:%1d:%f:%f:%1d:%f:%d:%d:%d:",
-                &volume, &crossfade, &jinglesvolume, &interludevol, &mixbackvol, &jingles_playing,
+                ":%03d:%03d:%03d:%03d:%03d:%03d:%d:%1d%1d%1d%1d%1d:%1d%1d:%1d:%1d%1d%1d%1d:%1d:%1d:%1d:%1d:%1d:%f:%f:%1d:%f:%d:%d:%d:",
+                &volume, &volume2, &crossfade, &jinglesvolume, &interludevol, &mixbackvol, &jingles_playing,
                 &left_stream, &left_audio, &right_stream, &right_audio, &stream_monitor,
-                &new_left_pause, &new_right_pause, &aux_on, &flush_left, &flush_right, &flush_jingles, &flush_interlude, &simple_mixer, &eot_alarm_set, &mixermode, &fadeout_f, &main_play, &(plr_l->newpbspeed), &(plr_r->newpbspeed), &speed_variance, &dj_audio_level, &crosspattern, &use_dsp, &twodblimit) !=30)
+                &new_left_pause, &new_right_pause, &aux_on, &flush_left, &flush_right, &flush_jingles, &flush_interlude, &simple_mixer, &eot_alarm_set, &mixermode, &fadeout_f, &main_play, &(plr_l->newpbspeed), &(plr_r->newpbspeed), &speed_variance, &dj_audio_level, &crosspattern, &use_dsp, &twodblimit) !=31)
             {
             fprintf(stderr, "mixer got bad mixer string\n");
             break;
             }
-
          eot_alarm_f |= eot_alarm_set;
 
          plr_l->fadeout_f = plr_r->fadeout_f = plr_j->fadeout_f = plr_i->fadeout_f = fadeout_f;
@@ -1912,11 +2008,11 @@ int main(int argc, char **argv)
          if (strcmp(mic1, "default"))
             {
             if (mic1[0] != '\0')
-               jack_connect(client, mic1, "idjc-mx:mic_in_1");
+               jack_connect(client, mic1, jack_port_name(mic_channel_1));
             }
          else
             if (inport && inport[0])
-               jack_connect(client, inport[0], "idjc-mx:mic_in_1");
+               jack_connect(client, inport[0], jack_port_name(mic_channel_1));
          }
          
       if (!strcmp(action, "remakemic2"))
@@ -1925,11 +2021,11 @@ int main(int argc, char **argv)
          if (strcmp(mic2, "default"))
             {
             if (mic2[0] != '\0')
-               jack_connect(client, mic2, "idjc-mx:mic_in_2");
+               jack_connect(client, mic2, jack_port_name(mic_channel_2));
             }
          else
             if (inport && inport[0] && inport[1])
-               jack_connect(client, inport[1], "idjc-mx:mic_in_2");
+               jack_connect(client, inport[1], jack_port_name(mic_channel_2));
          }
 
       if (!strcmp(action, "remakemic3"))
@@ -1938,11 +2034,11 @@ int main(int argc, char **argv)
          if (strcmp(mic3, "default"))
             {
             if (mic3[0] != '\0')
-               jack_connect(client, mic3, "idjc-mx:mic_in_3");
+               jack_connect(client, mic3, jack_port_name(mic_channel_3));
             }
          else
             if (inport && inport[0] && inport[1] && inport[2])
-               jack_connect(client, inport[2], "idjc-mx:mic_in_3");
+               jack_connect(client, inport[2], jack_port_name(mic_channel_3));
          }
          
       if (!strcmp(action, "remakemic4"))
@@ -1951,11 +2047,11 @@ int main(int argc, char **argv)
          if (strcmp(mic4, "default"))
             {
             if (mic4[0] != '\0')
-               jack_connect(client, mic4, "idjc-mx:mic_in_4");
+               jack_connect(client, mic4, jack_port_name(mic_channel_4));
             }
          else
             if (inport && inport[0] && inport[1] && inport[2] && inport[3])
-               jack_connect(client, inport[3], "idjc-mx:mic_in_4");
+               jack_connect(client, inport[3], jack_port_name(mic_channel_4));
          }
 
       if (!strcmp(action, "remakeaudl"))
@@ -1964,11 +2060,11 @@ int main(int argc, char **argv)
          if (strcmp(audl, "default"))
             {
             if (audl[0] != '\0')
-               jack_connect(client, "idjc-mx:dj_out_l", audl);
+               jack_connect(client, jack_port_name(audio_left_port), audl);
             }
          else
             if (outport)
-               jack_connect(client, "idjc-mx:dj_out_l", outport[0]);
+               jack_connect(client, jack_port_name(audio_left_port), outport[0]);
          }
       if (!strcmp(action, "remakeaudr"))
          {
@@ -1976,85 +2072,91 @@ int main(int argc, char **argv)
          if (strcmp(audr, "default"))
             {
             if (audr[0] != '\0')
-               jack_connect(client, "idjc-mx:dj_out_r", audr);
+               jack_connect(client, jack_port_name(audio_right_port), audr);
             }
          else
             if (outport && outport[1])
-               jack_connect(client, "idjc-mx:dj_out_r", outport[1]);
+               jack_connect(client, jack_port_name(audio_right_port), outport[1]);
          }
       if (!strcmp(action, "remakestrl"))
          {
          jack_port_disconnect(client, stream_left_port);
-         jack_connect(client, "idjc-mx:str_out_l", "idjc-sc:str_in_l");
+         jack_connect(client, jack_port_name(stream_left_port), our_sc_str_in_l);
          if (strcmp(strl, "default"))
             {
             if (strl[0] != '\0')
-               jack_connect(client, "idjc-mx:str_out_l", strl);
+               jack_connect(client, jack_port_name(stream_left_port), strl);
             }
          else
             if (outport && outport[1] && outport[2] && outport[3] && outport[4])
-               jack_connect(client, "idjc-mx:str_out_l", outport[4]);
+               jack_connect(client, jack_port_name(stream_left_port), outport[4]);
             else
                if(outport && outport[1] && outport[2])
-                  jack_connect(client, "idjc-mx:str_out_l", outport[2]);
+                  jack_connect(client, jack_port_name(stream_left_port), outport[2]);
          }
       if (!strcmp(action, "remakestrr"))
          {
          jack_port_disconnect(client, stream_right_port);
-         jack_connect(client, "idjc-mx:str_out_r", "idjc-sc:str_in_r");
+         jack_connect(client, jack_port_name(stream_right_port), our_sc_str_in_r);
          if (strcmp(strr, "default"))
             {
             if (strr[0] != '\0')
-               jack_connect(client, "idjc-mx:str_out_r", strr);
+               jack_connect(client, jack_port_name(stream_right_port), strr);
             }
          else
             if (outport && outport[1] && outport[2] && outport[3] && outport[4] && outport[5])
-               jack_connect(client, "idjc-mx:str_out_r", outport[5]);
+               jack_connect(client, jack_port_name(stream_right_port), outport[5]);
             else
                if (outport && outport[1] && outport[2] && outport[3])
-                  jack_connect(client, "idjc-mx:str_out_r", outport[3]);
+                  jack_connect(client, jack_port_name(stream_right_port), outport[3]);
          }
       if (!strcmp(action, "remakeauxl"))
          {
          jack_port_disconnect(client, aux_left_channel);
          if (auxl[0] != '\0')
-            jack_connect(client, auxl, "idjc-mx:aux_in_l");
+            jack_connect(client, auxl, jack_port_name(aux_left_channel));
          }
       if (!strcmp(action, "remakeauxr"))
          {
          jack_port_disconnect(client, aux_right_channel);
          if (auxr[0] != '\0')
-            jack_connect(client, auxr, "idjc-mx:aux_in_r");
+            jack_connect(client, auxr, jack_port_name(aux_right_channel));
+         }
+      if (!strcmp(action, "remakemidi"))
+         {
+         jack_port_disconnect(client, midi_port);
+         if (midi[0] != '\0')
+            jack_connect(client, midi, jack_port_name(midi_port));
          }
       if (!strcmp(action, "remakedol"))
          {
          jack_port_disconnect(client, dspout_left_port);
          if (dol[0] != '\0')
-            jack_connect(client, "idjc-mx:dsp_out_l" , dol);
+            jack_connect(client, jack_port_name(dspout_left_port), dol);
          }
       if (!strcmp(action, "remakedor"))
          {
          jack_port_disconnect(client, dspout_right_port);
          if (dor[0] != '\0')
-            jack_connect(client, "idjc-mx:dsp_out_r" , dor);
+            jack_connect(client, jack_port_name(dspout_right_port), dor);
          }
       if (!strcmp(action, "remakedil"))
          {
          jack_port_disconnect(client, dspin_left_port);
          if (dil[0] != '\0')
-            jack_connect(client, dil, "idjc-mx:dsp_in_l");
+            jack_connect(client, dil, jack_port_name(dspin_left_port));
          }
       if (!strcmp(action, "remakedir"))
          {
          jack_port_disconnect(client, dspin_right_port);
          if (dir[0] != '\0')
-            jack_connect(client, dir, "idjc-mx:dsp_in_r");
+            jack_connect(client, dir, jack_port_name(dspin_right_port));
          }
       if (!strcmp(action, "serverbind"))
          {
          fprintf(stderr, "remaking connection to server\n");
-         jack_connect(client, "idjc-mx:str_out_l", "idjc-sc:str_in_l"); 
-         jack_connect(client, "idjc-mx:str_out_r", "idjc-sc:str_in_r");
+         jack_connect(client, jack_port_name(stream_left_port), our_sc_str_in_l); 
+         jack_connect(client, jack_port_name(stream_right_port), our_sc_str_in_r);
          }
       if (!strcmp(action, "requestlevels"))
          {
@@ -2075,7 +2177,16 @@ int main(int argc, char **argv)
          mic_stats("mic_2_levels", mic_2);
          mic_stats("mic_3_levels", mic_3);
          mic_stats("mic_4_levels", mic_4);
-         
+
+         /* forward any MIDI commands that have been queued since last time */
+         pthread_mutex_lock(&midi_mutex);
+         midi_output[0]= '\0';
+         if (midi_nqueued>0) /* exclude leading `,`, include trailing `\0` */
+            memcpy(midi_output, midi_queue+1, midi_nqueued*sizeof(char));
+         midi_queue[0]= '\0';
+         midi_nqueued= 0;
+         pthread_mutex_unlock(&midi_mutex);
+
          fprintf(stdout, 
                    "str_l_peak=%d\nstr_r_peak=%d\n"
                    "str_l_rms=%d\nstr_r_rms=%d\n"
@@ -2095,6 +2206,7 @@ int main(int argc, char **argv)
                    "right_audio_runout=%d\n"
                    "left_additional_metadata=%d\n"
                    "right_additional_metadata=%d\n"
+                   "midi=%s\n"
                    "end\n",
                    str_l_peak_db, str_r_peak_db,
                    str_l_rms_db, str_r_rms_db,
@@ -2113,7 +2225,9 @@ int main(int argc, char **argv)
                    left_audio_runout && (!(plr_l->current_audio_context & 0x1)),
                    right_audio_runout && (!(plr_r->current_audio_context & 0x1)),
                    plr_l->dynamic_metadata.data_type,
-                   plr_r->dynamic_metadata.data_type);
+                   plr_r->dynamic_metadata.data_type,
+                   midi_output);
+
          /* tell the jack mixer it can reset its vu stats now */
          reset_vu_stats_f = TRUE;
          if (plr_l->dynamic_metadata.data_type)
@@ -2124,6 +2238,7 @@ int main(int argc, char **argv)
          }
       }
    alarm(0);
+   jack_deactivate(client);
    jack_client_close(client);
    client = NULL;
    free(fade_table);
@@ -2132,6 +2247,8 @@ int main(int argc, char **argv)
    free_dblookup_table();
    jack_free_ports(inport);
    jack_free_ports(outport);
+   free(our_sc_str_in_l);
+   free(our_sc_str_in_r);
    mic_free(mic_1);
    mic_free(mic_2);
    mic_free(mic_3);
