@@ -140,9 +140,11 @@ class jingles:
                self.interludevolume = self.interadj.get_value()
                self.interadj.set_value(100.0) 
                self.parent.deckadj.set_value(100.0)
+               self.parent.deck2adj.set_value(100.0)
             else:
                self.interludevolume = -1
                self.parent.deckadj.set_value(30.0)
+               self.parent.deck2adj.set_value(30.0)
          self.parent.deckadj.value_changed()
          string_to_send = "LOOP=0\nPLPL=%s\nACTN=playmanyjingles\nend\n" % self.pack_playlistlist(playlist)
          self.parent.mixer_write(string_to_send, True)
@@ -179,10 +181,11 @@ class jingles:
             self.stop.clicked() # this will take care of resetting the play button without triggering a flush
          if self.nomute == False:
             self.parent.deckadj.set_value(self.volume)
+            self.parent.deck2adj.set_value(self.volume)
+            if self.interludevolume != -1:
+               self.interadj.set_value(self.interludevolume)
          else:
             self.parent.send_new_mixer_stats()
-         if self.interludevolume != -1:
-            self.interadj.set_value(self.interludevolume)
          
    def delete_event(self, widget, event, data=None):
       self.window.hide()        # We don't really destroy the window
@@ -315,6 +318,7 @@ class jingles:
       self.window.set_icon_from_file(pkgdatadir + "icon" + gfext)
       self.window.add_events(gtk.gdk.KEY_PRESS_MASK)
       self.window.connect("key-press-event", parent.cb_key_capture)
+      self.window.connect("key-release-event", parent.cb_key_capture)
 
       hbox = gtk.HBox()
       hbox.set_spacing(8)
@@ -330,9 +334,10 @@ class jingles:
       self.vboxvol.pack_start(image, False, False, 0)
       image.show()
       
-      self.deckadj = gtk.Adjustment(0.0, 0.0, 105.0, 1.0, 6.0, 0.0)
+      self.deckadj = gtk.Adjustment(100.0, 0.0, 100.0, 1.0, 6.0, 0.0)
       self.deckadj.connect("value_changed", self.cb_deckvol)
       self.deckvol = gtk.VScale(self.deckadj)
+      self.deckvol.set_inverted(True)
       self.deckvol.set_update_policy(gtk.UPDATE_CONTINUOUS)
       self.deckvol.set_digits(1)
       self.deckvol.set_value_pos(gtk.POS_TOP)
@@ -355,9 +360,10 @@ class jingles:
       self.vboxinter.pack_start(image, False, False, 0)
       image.show()
       
-      self.interadj = gtk.Adjustment(75.0, 0.0, 100.0, 1.0, 6.0, 0.0)
+      self.interadj = gtk.Adjustment(65.0, 0.0, 100.0, 1.0, 6.0, 0.0)
       self.interadj.connect("value_changed", self.cb_intervol)
       self.intervol = gtk.VScale(self.interadj)
+      self.intervol.set_inverted(True)
       self.intervol.set_update_policy(gtk.UPDATE_CONTINUOUS)
       self.intervol.set_digits(1)
       self.intervol.set_value_pos(gtk.POS_TOP)
