@@ -198,6 +198,14 @@ channels = "Channels:"
 
 common_volume_control_tip = "The volume control shared by both music players."
 
+connection_dialog_title_add = "Enter new server connection details"
+
+connection_dialog_title_edit = "Edit existing server connection details"
+
+left_volume_control_tip = "The volume control for the left music player."
+
+right_volume_control_tip = "The volume control for the right music player."
+
 comp_attack = "Attack"
 
 comp_bar = "Comp"
@@ -232,7 +240,7 @@ conn_col_host = "Hostname/IP"
 
 conn_col_port = "Port"
 
-conn_col_mount = "Mount point"
+conn_col_mount = "Mount point      "
 
 conn_col_listeners = "Listeners"
 
@@ -240,7 +248,7 @@ connect_disconnect_nonconfig = "Server Not Configured"
 
 connected_to_history = "connected to"
 
-connection = " Connection "
+connection = "Connection"
 
 connection_lost = "Connection Lost"
 
@@ -250,13 +258,13 @@ connection_icecast2 = " Connection: Icecast 2 server "
 
 connection_shoutcast = " Connection: Shoutcast server "
 
-connections_table_tip = "A table of servers with which to connect. Only one master server can be added for the purpose of streaming. All other servers will appear below the master server in the list for the purpose of stats collection which can be toggled on a per server basis by the check button in the left hand column. The type column consists of a code pertaining to the type of server: Icecast2/Shoutcast, Master/Relay."
+connections_table_tip = "A table of servers with which to connect. Only one master server can be added for the purpose of streaming. All other servers will appear below the master server in the list for the purpose of stats collection which can be toggled on a per server basis."
 
 connections_add_tip = "Click this to add server information from the entry boxes below into the table above. Fields below cannot be left blank or else nothing will happen."
 
 connections_editremove_tip = "Click this when you want to remove a server from the list above for editing/removal. Highlight the particular server first. The information will be transferred to the entry boxes below."
 
-contact_info = " Shoutcast Contact Info "
+contact_details = " Contact Details "
 
 contrib_label = "Contributors"
 
@@ -288,8 +296,24 @@ crossfader_tip = "The crossfader."
 
 crosspass = "Pass"
 
+cue_description = "Description"
+
+cue_duration = "Duration"
+
+cue_index = "Index"
+
+cue_index_abbrev = "Ind"
+
+cue_play = "Play"
+
+cue_track = "Track"
+
+cue_track_abbrev = "Trk"
+
 cue_up = "Cue Up"
 
+cuesheet_playlist = " Cuesheet Playlist "
+
 dbalbum = "Album"
 
 dbartist = "Artist"
@@ -426,6 +450,8 @@ external_playlist = "Choose a playlist file."
 
 external_directory = "Choose a folder/directory of music."
 
+extra_info = "Stream Info"
+
 fade_none_menu = "No Fade"
 
 fade_5_menu = "Fade 5s"
@@ -464,7 +490,7 @@ flacmetadata = "Metadata"
 
 flacmetadata_tip = "You can prevent the sending of metadata by turning this feature off. This will prevent certain players from dropping the stream or inserting an audible gap every time the song title changes."
 
-format = " Format "
+format = "Format"
 
 format_info_bar_tip = "Information about how the encoder is currently configured is displayed here."
 
@@ -482,11 +508,11 @@ gather_stats_tip = "Setting this will cause IDJC to attempt to obtain the number
 
 general_tab = "General"
 
-genre = "Genre:"
+genre = "Genre(s):"
 
 genre_tip = "The musical genres you are likely to play."
 
-get_stats = "Get listener stats:"
+get_stats = "Obtain audience stats:"
 
 get_stats_never = "Never"
 
@@ -516,6 +542,8 @@ hostname_tip = """The hostname of the server.
 Example 1: 192.168.1.4
 Example 2: localhost"""
 
+hostname2 = "Hostname:"
+
 hysteresis = "Hyster."
 
 icy_aim = "AIM:"
@@ -565,6 +593,8 @@ in_dj_mix_tip = "Make the microphone audio audible in the DJ mix. This may not a
 
 initial_player_settings = "Player Settings At Startup"
 
+individual_controls = "Individual Controls"
+
 interval = "Interval:"
 
 invert_left = "Invert left mic audio"
@@ -605,7 +635,9 @@ Possible remedies would be to close the other audio app or configure the sound s
 If you are trying to connect to a named jack server, either set the environment variable JACK_DEFAULT_SERVER to that name or launch IDJC with the -j jackservername option. For example:
 
          $ jackd -n xyzzy -d alsa -r 44100 -p 2048 &
-         $ idjc -p profilename -j xyzzy"""
+         $ idjc -p profilename -j xyzzy
+
+If you are trying to open multiple instances of IDJC use the -e command line switch."""
 
 jack_entry = """Enter the name of the JACK audio port with which to bind and then click the set button to the right.
 Typing 'jack_lsp -p' in a console will give you a list of valid JACK audio ports. Note that inputs will only bind to output ports and outputs will only bind to input ports."""
@@ -670,10 +702,6 @@ listen_url = "Listen URL:"
 
 listen_url_tip = "The URL of your radio station. This and the rest of the information below is intended for display on a radio station listings website."
 
-listeners_failed = "Failed"
-
-listeners_unknown = "Unknown"
-
 listeners_total_tip = "The sum total of listeners in this server tab."
 
 lmic_toggle_tip = "This button toggles the left microphone input."
@@ -682,10 +710,16 @@ localhost = "Localhost"
 
 login_tip = "Icecast servers require a login password. On a server where no fixed mountpoints have been configured the source login will be 'source'. For collecting stats the admin password can be given for which the login is by default, 'admin' but could have been changed to something else. Stats may be collected with a source login provided the mountpoint matches."
 
+loginname = "Login name:"
+
 loop_all = "Loop All"
 
 lower_vorbis = "Lower %"
 
+master_login = "Master server admin password:"
+
+master_login_tip = "This is for kick and stats on Shoutcast master servers that have an administrator password. For those that don't leave this blank (the source password is sufficient for those)."
+
 make_public = "Make Public"
 
 make_public_tip = "Publish your radio station on a listings website. The website in question will depend on how the server to which you connect is configured."
@@ -784,6 +818,8 @@ monitor_stream = "Stream"
 
 mono = "Mono"
 
+mountpoint = "Mount point:"
+
 mount_point_tip = "The mount point, which is not required when dealing with Shoutcast servers. A typical mount point might be /listen or /listen.ogg. It is recommended that Ogg streams have a mount point ending in .ogg for the sake of listener client compatibility."
 
 mp3_compat_tip = "The type of mpeg header used in the mp3 stream or either s-rate or freeformat. Freeformat indicates that the bitrate is not specified in the header since it is non-standard, rather the listener client has to figure out what the bitrate is by itself and not all of them are capable of doing that. In short you'll be streaming something many listeners may not be able to listen to. S-rate indicates the sample rate you have selected is not compatible with mp3 and you'll need to change it if you want to stream."
@@ -892,6 +928,8 @@ This control maintains constant audio power throughout its range of travel, givi
 
 If you require 0dB straight down the middle then this feature should be turned off."""
 
+password = "Password:"
+
 pass_button_tip = "This button causes the crossfader to move to the opposite side at a speed determined by the speed selector to the left."
 
 pass_speed_tip = "The time in seconds that the crossfader will take to automatically pass across when the button to the right is clicked."
@@ -976,6 +1014,8 @@ popupwindowtracktotal = "Total number of tracks %d"
 
 port = "Port"
 
+portnumber = "Port number:"
+
 port_tip = "The base port number which the server is using."
 
 prefs_button = "Prefs"
@@ -992,7 +1032,7 @@ previous_tip = "Previous track."
 
 profile_already_in_use = """IDJC could not be started because the profile is currently in use by another instance of IDJC.
 
-If you wish to run more than one instance of IDJC concurrently then in addition to using a different profile you also need to be running an additional JACK sound server.
+If you wish to run more than one instance of IDJC concurrently then in addition to using a different profile you also need to be using the -e command line switch or running on a different JACK sound server.
 
 For further information refer to the -p and -j command line options in the IDJC man page and also to the -n option for starting jackd."""
 
@@ -1006,6 +1046,8 @@ prokyon3_database = "Database:"
 
 prokyon3_frame_text = "Prokyon3 (song title) Database"
 
+prokyon3_hostname = "Hostname:"
+
 prokyon3_nosql = "Python module MySQLdb required"
 
 prokyon3_password = "Password:"
@@ -1162,7 +1204,7 @@ server_passwd = "Pass:"
 
 server_port = "Port:"
 
-server_type = "Type:"
+servertype = "Server type:"
 
 server_type_icecast2 = "Icecast 2"
 
@@ -1175,14 +1217,16 @@ server_type_codes = ("I2M", "SM", "I2R", "SR")
 server_type_labels = ("Icecast 2 Master", "Shoutcast Master",
                       "Icecast 2 Stats/Relay", "Shoutcast Stats/Relay")
 
-stream_details = "Server Details & Stream Format"
+stream_details = "Configuration"
 
-stream_details_tip = "The user interface for changing server connection details and the stream format, e.g. mp3 or vorbis, is contained within. Be sure to scroll down and enter as much information as is necessary."
+stream_details_tip = "The controls for configuring a stream."
 
 output_window_title = "IDJC Output"
 
 output_window_open_tip = "Open the output window."
 
+server_dialog_stats = "Server to be scanned for audience figures"
+
 set = "Set"
 
 set_tip = "Reroute the audio to/from the specified port"
@@ -1197,6 +1241,8 @@ silence_killer = "End tracks early: those that have quiet endings"
 
 sharp = "Sharp"
 
+shoutcast_extra = "Extra Shoutcast"
+
 shell_commands_tip = "Enter bash shell commands to run, separated by a semicolon for this particular event."
 
 show_microphone_meters = "Microphone Meters"
@@ -1253,10 +1299,14 @@ show_stream_meters = "Stream Audio Levels And Connections"
 
 stereo = "Stereo"
 
+jump_to_top_control_element = "Jump To Top"
+
 stop_control_element = "Player stop"
 
 stop_control_menu = "Player stop"
 
+jump_to_top_control_menu = "Jump To Top"
+
 stop_jingles_tip = "Stop playing jingles."
 
 stop_rec_tip = "Stop recording."
@@ -1385,6 +1435,8 @@ twodblimit_tip = "This option may improve the audio quality at the expense of a
 
 unexpected = "A connection to a radio server failed."
 
+unknown = "Unknown"
+
 unp_controls = "Unprocessed Audio Controls"
 
 unp_left = "Left"
@@ -1403,7 +1455,7 @@ update_encoder_settings_tip = """Use this to change the encoder settings while s
  
 If this button is greyed out it means that the encoder is not running, or the bitrate/samplerate combination is not supported by the encoder, or you are trying to switch between Ogg and mp3, which is not permitted."""
 
-upon_connection = "Upon connection:"
+upon_connection = "At connect:"
 
 upper_vorbis = "Upper %"
 
@@ -1445,3 +1497,164 @@ xchat_install_done = "The XChat Plugin Is Already Installed"
 
 xchat_install_failed = "The Plugin Would Not Install -- Try Again?"
 
+dual_volume = "Separate left/right volume faders"
+dual_volume_tip = "Tick this option to use an independent volume fader for the left and right music players."
+
+control_sources= {
+    'c': 'MIDI control',
+    'n': 'MIDI note',
+    'p': 'MIDI pitch-wheel',
+    'k': 'Keyboard press',
+    'x': 'XChat command'
+}
+control_modes= {
+    'd': 'Direct fader/held button',
+    'p': 'One-shot/toggle button',
+    's': 'Set value',
+    'a': 'Alter value'
+}
+
+control_target_singular= 'Singular control'
+
+control_targets= {
+    'p': 'Player',
+    'm': 'Mic',
+    'k': 'Jingle',
+    's': 'Stream',
+    'r': 'Recorder'
+}
+control_targets_players= (
+    'Left player',
+    'Right player',
+    'Focused player',
+    "Fadered player",
+)
+control_method_groups= {
+    'c': 'Preferences',
+    'p': 'Player',
+    'x': 'Both players',
+    'm': 'Microphone',
+    'v': 'VoIP channel',
+    'a': 'Aux channel',
+    'k': 'Single jingle',
+    'j': 'Jingle player',
+    's': 'Stream',
+    'r': 'Stream recorder',
+}
+control_methods= {
+    'c_tips': 'Prefs enable tooltips',
+
+    'p_pp': 'Player play/pause',
+    'p_stop': 'Player stop',
+    'p_advance': 'Player advance',
+    'p_prev': 'Player play previous',
+    'p_next': 'Player play next',
+    'p_sfire': 'Player play selected from start',
+    'p_sprev': 'Player select previous',
+    'p_snext': 'Player select next',
+    'p_stream': 'Player stream output enable',
+    'p_listen': 'Player DJ output enable',
+    'p_prep': 'Player DJ-only switch',
+    'p_vol': 'Player set volume',
+    'p_gain': 'Player set gain',
+    'p_pan': 'Player set balance',
+    'p_pitch': 'Player set pitchbend',
+
+    'p_tag': 'Playlist edit tags',
+    'p_istop': 'Playlist insert stop',
+    'p_ianno': 'Playlist insert announce',
+    'p_itrans': 'Playlist insert transfer',
+    'p_ifade': 'Playlist insert crossfade',
+    'p_ipitch': 'Playlist insert pitchunbend',
+    'p_igotop': 'Playlist insert jump to top',
+
+    'x_fade': 'Players set crossfade',
+    'x_pass': 'Players pass crossfade',
+    'x_focus': 'Players set focus',
+    'x_pitch': 'Players show pitchbend',
+
+    'm_on': 'Mic output enable',
+    'm_vol': 'Mic set volume',
+    'm_gain': 'Mic set gain',
+    'm_pan': 'Mic set balance',
+
+    'v_on': 'VoIP output enable',
+    'v_prep': 'VoIP DJ-only switch',
+    'v_vol': 'VoIP set volume',
+    'v_gain': 'VoIP set gain',
+    'v_pan': 'VoIP set balance',
+
+    'a_on': 'Aux output enable',
+    'a_vol': 'Aux set volume',
+    'a_gain': 'Aux set gain',
+    'a_pan': 'Aux set balance',
+
+    'k_fire': 'Jingle play from start',
+
+    'j_ps': 'Jingles play/stop',
+    'j_playex': 'Jingles play exclusive',
+    'j_sprev': 'Jingles select previous',
+    'j_snext': 'Jingles select next',
+    'j_sfire': 'Jingles play selected from start',
+    'j_vol': 'Jingles set jingles volume',
+    'j_ivol': 'Jingles set interlude volume',
+
+    's_on': 'Stream set connected',
+
+    'r_on': 'Recorder set recording',
+}
+
+pulse_on_press= 'Pressed'
+pulse_on_release= 'Released'
+
+ctrltab_label= 'Bindings'
+ctrltab_column_input= 'Input'
+ctrltab_column_action= 'Action'
+ctrltab_column_target= 'Target'
+ctrltab_button_new= 'New'
+ctrltab_button_remove= 'Remove'
+ctrltab_button_edit= 'Edit'
+ctrltab_without_target= 'Singular control'
+
+binding_title= 'Edit control binding'
+binding_input= ' Input '
+binding_action= ' Action '
+
+binding_learn= 'Listen for input...'
+binding_learn_on= 'Listening for input'
+binding_source= 'Source'
+binding_channel_midi= 'Channel'
+binding_channel_key= 'Shifting'
+binding_controls= {
+    'c': 'Control',
+    'n': 'Note',
+    'p': 'Control',
+    'k': 'Key',
+}
+
+binding_mode= 'Interaction'
+binding_target= 'On target'
+binding_values= {
+    'd': 'Use value', 
+    'p': 'Act if', 
+    's': 'Set to',
+    'a': 'Adjust by',
+}
+
+inverted_value= 'Reversed'
+
+binding_input_tip= """No binding would be complete without an input. In this case a press of a keyboard key or an event from a midi device.
+
+Input selection can be done manually or with the help of the 'Listen for input' option."""
+binding_action_tip= """The top option tersely describes a user interface feature of which there may be multiples - see 'On target' for how to select those.
+
+'Interaction' describes how the control input will be used:
+'Direct fader/held button' tracks the input state at all times. Useful if you want a push to talk button or to track directly the position of a a midi fader.
+
+'One-shot/toggle button' acts like a trigger, activating on button presses with releases doing nothing.
+
+'Set value' This allows setting specific values like fader positions or setting a state fully on/off where no between values are allowed.
+
+'Adjust by' A single press will reduce or increase a value, e.g. a fader position will move by a certain amount.
+
+Only a subset of interaction options may be available to perform a specific action as others might not make any sense."""
